==> react-nlp-jt-0.0.13.tgz: package/src/index.js <==
// @flow

import React from "react"
import ReactDOM from "react-dom"
import Theme from "./components/Theme"
import DemoSite from "./components/DemoSite"
import DatasetViewer from "./components/DatasetViewer"
import NLPAnnotator from './components/NLPAnnotator'
const labels = [
  {
    id: "gryffindor",
    displayName: "Gryffindor",
    description: "Daring, strong nerve and chivalry."
  },
  {
    id: "slytherin",
    displayName: "Slytherin",
    description: "Cunning and ambitious. Possibly dark wizard."
  }
];


class NLPAnnotatorTest extends React.Component {
  state = {
    text: "Harry was an honest to god good man"
  }
  render () {

    return (
      <div>
        <button onClick={() => {this.setState({text: 'alex are mere'}) }}> next </button>
        <NLPAnnotator
          type="label-relationships"
          // labels={labels}
          multipleLabels={false}
          showHeader={false}
          document={this.state.text}
          onChange={(output) => {
            console.log("Output is...", output);
          }}
          entityLabels={labels}
          relationshipLabels={labels}

          initialRelationships={[
            {
              from: "1cf4577f-e3b8-40ce-8ce7-dd776d57b687",
              to: '0ceb376c-c102-4f49-8bf0-f799f2e732e4',
              label: 'slytherin',
              color: 'blue',
            }
          ]}
          initialSequence={[
            {
              text: 'Cunning',
              label: 'slytherin',
              color: 'red',
              textId: "1cf4577f-e3b8-40ce-8ce7-dd776d57b687"
            },
            {
              text: ' ',
              textId: 'myfh40'
            },
            {
              text: 'alex',
              label: 'slytherin',
              color: 'blue',
              textId: '0ceb376c-c102-4f49-8bf0-f799f2e732e4'
            }
          ]}
        />
      </div>
    )
  }
}
ReactDOM.render(
  <Theme>
    {window.location.search.includes("load_url") ? (
      <DatasetViewer />
    ) : (
      <NLPAnnotatorTest/>
    )}
  </Theme>,
  document.getElementById("root")
)

==> react-nlp-jt-0.0.14.tgz: package/src/index.js <==
// @flow

import React from "react"
import ReactDOM from "react-dom"
import Theme from "./components/Theme"
import DemoSite from "./components/DemoSite"
import DatasetViewer from "./components/DatasetViewer"
import NLPAnnotator from './components/NLPAnnotator'
const labels = [
  {
    id: "gryffindor",
    displayName: "Gryffindor",
    description: "Daring, strong nerve and chivalry."
  },
  {
    id: "slytherin",
    displayName: "Slytherin",
    description: "Cunning and ambitious. Possibly dark wizard."
  }
];


class NLPAnnotatorTest extends React.Component {
  state = {
    text: "Harry was an honest to god good man"
  }
  render () {

    return (
      <div>
        <button onClick={() => {this.setState({text: 'alex are mere'}) }}> next </button>
        <NLPAnnotator
          type="label-relationships"
          // labels={labels}
          multipleLabels={false}
          showHeader={false}
          document={this.state.text}
          onChange={(output) => {
            console.log("Output is...", output);
          }}
          entityLabels={labels}
          relationshipLabels={labels}

          // initialRelationships={[
          //   {
          //     from: "1cf4577f-e3b8-40ce-8ce7-dd776d57b687",
          //     to: '0ceb376c-c102-4f49-8bf0-f799f2e732e4',
          //     label: 'slytherin',
          //     color: 'blue',
          //   }
          // ]}
          // initialSequence={[
          //   {
          //     text: 'Cunning',
          //     label: 'slytherin',
          //     color: 'red',
          //     textId: "1cf4577f-e3b8-40ce-8ce7-dd776d57b687"
          //   },
          //   {
          //     text: ' ',
          //     textId: 'myfh40'
          //   },
          //   {
          //     text: 'alex',
          //     label: 'slytherin',
          //     color: 'blue',
          //     textId: '0ceb376c-c102-4f49-8bf0-f799f2e732e4'
          //   }
          // ]}
        />
      </div>
    )
  }
}
ReactDOM.render(
  <Theme>
    {window.location.search.includes("load_url") ? (
      <DatasetViewer />
    ) : (
      <NLPAnnotatorTest/>
    )}
  </Theme>,
  document.getElementById("root")
)
